# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


class DivBlendMode(str, enum.Enum):
    SOURCE_IN = "source_in"
    SOURCE_ATOP = "source_atop"
    DARKEN = "darken"
    LIGHTEN = "lighten"
    MULTIPLY = "multiply"
    SCREEN = "screen"



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Scrolls scrollable container from current position by `item_count` or by
# `offset`, if both provided scroll action will be combined, negative numbers
# associated with backward scroll.
class DivActionScrollBy(BaseDiv):

    def __init__(
        self, *,
        type: str = "scroll_by",
        animated: typing.Optional[typing.Union[Expr, bool]] = None,
        id: typing.Optional[typing.Union[Expr, str]] = None,
        item_count: typing.Optional[typing.Union[Expr, int]] = None,
        offset: typing.Optional[typing.Union[Expr, int]] = None,
        overflow: typing.Optional[typing.Union[Expr, DivActionScrollByOverflow]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            animated=animated,
            id=id,
            item_count=item_count,
            offset=offset,
            overflow=overflow,
            **kwargs,
        )

    type: str = Field(default="scroll_by")
    animated: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "If `true` (default value) scroll will be animated, else "
            "not."
        ),
    )
    id: typing.Union[Expr, str] = Field(
        description="Identifier of the view that is going to be manipulated.",
    )
    item_count: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Count of container items to scroll, negative value is "
            "associated with backwardscroll."
        ),
    )
    offset: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Distance to scroll measured in `dp` from current position, "
            "negative value isassociated with backward scroll. "
            "Applicable only in `gallery`."
        ),
    )
    overflow: typing.Optional[typing.Union[Expr, DivActionScrollByOverflow]] = Field(
        description=(
            "Specifies how navigation will occur when the boundary "
            "elements arereached:`clamp` — Transition will stop at the "
            "boundary element (defaultvalue);`ring` — Transition will be "
            "to the beginning or the end depending on thecurrent "
            "element."
        ),
    )


class DivActionScrollByOverflow(str, enum.Enum):
    CLAMP = "clamp"
    RING = "ring"


DivActionScrollBy.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_action_scroll_destination


# Scrolls or switches container to given destination provided by `destination`.
class DivActionScrollTo(BaseDiv):

    def __init__(
        self, *,
        type: str = "scroll_to",
        animated: typing.Optional[typing.Union[Expr, bool]] = None,
        destination: typing.Optional[div_action_scroll_destination.DivActionScrollDestination] = None,
        id: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            animated=animated,
            destination=destination,
            id=id,
            **kwargs,
        )

    type: str = Field(default="scroll_to")
    animated: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "If `true` (default value) scroll will be animated, else "
            "not."
        ),
    )
    destination: div_action_scroll_destination.DivActionScrollDestination = Field(
        description=(
            "Specifies destination of scroll:`index` - scroll or switch "
            "to item with indexprovided by `value`;`offset` - scroll to "
            "position measured in `dp` fromcontainer\'s start and "
            "provided by `value`. Applicable only in `gallery`;`start` "
            "-scrolls to start of container;`end` - scrolls to end of "
            "container.."
        ),
    )
    id: typing.Union[Expr, str] = Field(
        description="Identifier of the view that is going to be manipulated.",
    )


DivActionScrollTo.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_typed_value


# Sets the value in the array by index.
class DivActionArraySetValue(BaseDiv):

    def __init__(
        self, *,
        type: str = "array_set_value",
        index: typing.Optional[typing.Union[Expr, int]] = None,
        value: typing.Optional[div_typed_value.DivTypedValue] = None,
        variable_name: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            index=index,
            value=value,
            variable_name=variable_name,
            **kwargs,
        )

    type: str = Field(default="array_set_value")
    index: typing.Union[Expr, int] = Field(
    )
    value: div_typed_value.DivTypedValue = Field(
    )
    variable_name: typing.Union[Expr, str] = Field(
    )


DivActionArraySetValue.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing
from typing import Union

from pydivkit.core import BaseDiv, Expr, Field

from . import (
    end_destination, index_destination, offset_destination, start_destination,
)


DivActionScrollDestination = Union[
    offset_destination.OffsetDestination,
    index_destination.IndexDestination,
    start_destination.StartDestination,
    end_destination.EndDestination,
]



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_corners_radius, div_shadow, div_stroke


# Stroke around the element.
class DivBorder(BaseDiv):

    def __init__(
        self, *,
        corner_radius: typing.Optional[typing.Union[Expr, int]] = None,
        corners_radius: typing.Optional[div_corners_radius.DivCornersRadius] = None,
        has_shadow: typing.Optional[typing.Union[Expr, bool]] = None,
        shadow: typing.Optional[div_shadow.DivShadow] = None,
        stroke: typing.Optional[div_stroke.DivStroke] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            corner_radius=corner_radius,
            corners_radius=corners_radius,
            has_shadow=has_shadow,
            shadow=shadow,
            stroke=stroke,
            **kwargs,
        )

    corner_radius: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "One radius of element and stroke corner rounding. Has a "
            "lower priority than`corners_radius`."
        ),
    )
    corners_radius: typing.Optional[div_corners_radius.DivCornersRadius] = Field(
        description="Multiple radii of element and stroke corner rounding.",
    )
    has_shadow: typing.Optional[typing.Union[Expr, bool]] = Field(
        description="Adding shadow.",
    )
    shadow: typing.Optional[div_shadow.DivShadow] = Field(
        description="Parameters of the shadow applied to the element stroke.",
    )
    stroke: typing.Optional[div_stroke.DivStroke] = Field(
        description="Stroke style.",
    )


DivBorder.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Extension that affects an element.
class DivExtension(BaseDiv):

    def __init__(
        self, *,
        id: typing.Optional[typing.Union[Expr, str]] = None,
        params: typing.Optional[typing.Dict[str, typing.Any]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            id=id,
            params=params,
            **kwargs,
        )

    id: typing.Union[Expr, str] = Field(
        description="Extension ID.",
    )
    params: typing.Optional[typing.Dict[str, typing.Any]] = Field(
        description="Additional extension parameters.",
    )


DivExtension.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


class DivTransitionSelector(str, enum.Enum):
    NONE = "none"
    DATA_CHANGE = "data_change"
    STATE_CHANGE = "state_change"
    ANY_CHANGE = "any_change"



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import (
    div, div_accessibility, div_action, div_alignment_horizontal,
    div_alignment_vertical, div_animator, div_appearance_transition,
    div_background, div_border, div_change_transition,
    div_collection_item_builder, div_disappear_action, div_edge_insets,
    div_extension, div_fixed_size, div_focus, div_function, div_layout_provider,
    div_page_transformation, div_pager_layout_mode, div_size, div_tooltip,
    div_transform, div_transition_trigger, div_trigger, div_variable,
    div_visibility, div_visibility_action,
)


# Pager. It contains a horizontal set of cards that can be scrolled page by page.
# It shows the main page and the beginning of the next one.
class DivPager(BaseDiv):

    def __init__(
        self, *,
        type: str = "pager",
        accessibility: typing.Optional[div_accessibility.DivAccessibility] = None,
        alignment_horizontal: typing.Optional[typing.Union[Expr, div_alignment_horizontal.DivAlignmentHorizontal]] = None,
        alignment_vertical: typing.Optional[typing.Union[Expr, div_alignment_vertical.DivAlignmentVertical]] = None,
        alpha: typing.Optional[typing.Union[Expr, float]] = None,
        animators: typing.Optional[typing.Sequence[div_animator.DivAnimator]] = None,
        background: typing.Optional[typing.Sequence[div_background.DivBackground]] = None,
        border: typing.Optional[div_border.DivBorder] = None,
        column_span: typing.Optional[typing.Union[Expr, int]] = None,
        default_item: typing.Optional[typing.Union[Expr, int]] = None,
        disappear_actions: typing.Optional[typing.Sequence[div_disappear_action.DivDisappearAction]] = None,
        extensions: typing.Optional[typing.Sequence[div_extension.DivExtension]] = None,
        focus: typing.Optional[div_focus.DivFocus] = None,
        functions: typing.Optional[typing.Sequence[div_function.DivFunction]] = None,
        height: typing.Optional[div_size.DivSize] = None,
        id: typing.Optional[typing.Union[Expr, str]] = None,
        infinite_scroll: typing.Optional[typing.Union[Expr, bool]] = None,
        item_builder: typing.Optional[div_collection_item_builder.DivCollectionItemBuilder] = None,
        item_spacing: typing.Optional[div_fixed_size.DivFixedSize] = None,
        items: typing.Optional[typing.Sequence[div.Div]] = None,
        layout_mode: typing.Optional[div_pager_layout_mode.DivPagerLayoutMode] = None,
        layout_provider: typing.Optional[div_layout_provider.DivLayoutProvider] = None,
        margins: typing.Optional[div_edge_insets.DivEdgeInsets] = None,
        orientation: typing.Optional[typing.Union[Expr, DivPagerOrientation]] = None,
        paddings: typing.Optional[div_edge_insets.DivEdgeInsets] = None,
        page_transformation: typing.Optional[div_page_transformation.DivPageTransformation] = None,
        restrict_parent_scroll: typing.Optional[typing.Union[Expr, bool]] = None,
        reuse_id: typing.Optional[typing.Union[Expr, str]] = None,
        row_span: typing.Optional[typing.Union[Expr, int]] = None,
        selected_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        tooltips: typing.Optional[typing.Sequence[div_tooltip.DivTooltip]] = None,
        transform: typing.Optional[div_transform.DivTransform] = None,
        transition_change: typing.Optional[div_change_transition.DivChangeTransition] = None,
        transition_in: typing.Optional[div_appearance_transition.DivAppearanceTransition] = None,
        transition_out: typing.Optional[div_appearance_transition.DivAppearanceTransition] = None,
        transition_triggers: typing.Optional[typing.Sequence[typing.Union[Expr, div_transition_trigger.DivTransitionTrigger]]] = None,
        variable_triggers: typing.Optional[typing.Sequence[div_trigger.DivTrigger]] = None,
        variables: typing.Optional[typing.Sequence[div_variable.DivVariable]] = None,
        visibility: typing.Optional[typing.Union[Expr, div_visibility.DivVisibility]] = None,
        visibility_action: typing.Optional[div_visibility_action.DivVisibilityAction] = None,
        visibility_actions: typing.Optional[typing.Sequence[div_visibility_action.DivVisibilityAction]] = None,
        width: typing.Optional[div_size.DivSize] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            accessibility=accessibility,
            alignment_horizontal=alignment_horizontal,
            alignment_vertical=alignment_vertical,
            alpha=alpha,
            animators=animators,
            background=background,
            border=border,
            column_span=column_span,
            default_item=default_item,
            disappear_actions=disappear_actions,
            extensions=extensions,
            focus=focus,
            functions=functions,
            height=height,
            id=id,
            infinite_scroll=infinite_scroll,
            item_builder=item_builder,
            item_spacing=item_spacing,
            items=items,
            layout_mode=layout_mode,
            layout_provider=layout_provider,
            margins=margins,
            orientation=orientation,
            paddings=paddings,
            page_transformation=page_transformation,
            restrict_parent_scroll=restrict_parent_scroll,
            reuse_id=reuse_id,
            row_span=row_span,
            selected_actions=selected_actions,
            tooltips=tooltips,
            transform=transform,
            transition_change=transition_change,
            transition_in=transition_in,
            transition_out=transition_out,
            transition_triggers=transition_triggers,
            variable_triggers=variable_triggers,
            variables=variables,
            visibility=visibility,
            visibility_action=visibility_action,
            visibility_actions=visibility_actions,
            width=width,
            **kwargs,
        )

    type: str = Field(default="pager")
    accessibility: typing.Optional[div_accessibility.DivAccessibility] = Field(
        description="Accessibility settings.",
    )
    alignment_horizontal: typing.Optional[typing.Union[Expr, div_alignment_horizontal.DivAlignmentHorizontal]] = Field(
        description=(
            "Horizontal alignment of an element inside the parent "
            "element."
        ),
    )
    alignment_vertical: typing.Optional[typing.Union[Expr, div_alignment_vertical.DivAlignmentVertical]] = Field(
        description=(
            "Vertical alignment of an element inside the parent element."
        ),
    )
    alpha: typing.Optional[typing.Union[Expr, float]] = Field(
        description=(
            "Sets transparency of the entire element: `0` — completely "
            "transparent, `1` —opaque."
        ),
    )
    animators: typing.Optional[typing.Sequence[div_animator.DivAnimator]] = Field(
        description=(
            "Declaration of animators that change variable values over "
            "time."
        ),
    )
    background: typing.Optional[typing.Sequence[div_background.DivBackground]] = Field(
        description="Element background. It can contain multiple layers.",
    )
    border: typing.Optional[div_border.DivBorder] = Field(
        description="Element stroke.",
    )
    column_span: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Merges cells in a column of the [grid](div-grid.md) "
            "element."
        ),
    )
    default_item: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Ordinal number of the pager element that will be opened by "
            "default."
        ),
    )
    disappear_actions: typing.Optional[typing.Sequence[div_disappear_action.DivDisappearAction]] = Field(
        description="Actions when an element disappears from the screen.",
    )
    extensions: typing.Optional[typing.Sequence[div_extension.DivExtension]] = Field(
        description=(
            "Extensions for additional processing of an element. The "
            "list of extensions isgiven in "
            "[DivExtension](../../extensions)."
        ),
    )
    focus: typing.Optional[div_focus.DivFocus] = Field(
        description="Parameters when focusing on an element or losing focus.",
    )
    functions: typing.Optional[typing.Sequence[div_function.DivFunction]] = Field(
        description="User functions.",
    )
    height: typing.Optional[div_size.DivSize] = Field(
        description=(
            "Element height. For Android: if there is text in this or in "
            "a child element,specify height in `sp` to scale the element "
            "together with the text. To learn moreabout units of size "
            "measurement, see [Layout inside the card](../../layout)."
        ),
    )
    id: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "Element ID. It must be unique within the root element. It "
            "is used as`accessibilityIdentifier` on iOS."
        ),
    )
    infinite_scroll: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "Enables infinite scrolling of cards. Scrolling is looped: "
            "after the last card isdisplayed, it starts over again."
        ),
    )
    item_builder: typing.Optional[div_collection_item_builder.DivCollectionItemBuilder] = Field(
        description=(
            "Sets collection elements dynamically using `data` and "
            "`prototypes`."
        ),
    )
    item_spacing: typing.Optional[div_fixed_size.DivFixedSize] = Field(
        description="Spacing between elements.",
    )
    items: typing.Optional[typing.Sequence[div.Div]] = Field(
        description=(
            "Pager elements. Page-by-page transition options can be "
            "implementedusing:`div-action://set_current_item?id=&item=` "
            "— set the current page with anordinal number `item` inside "
            "an element, with the "
            "specified`id`;`div-action://set_next_item?id=[&overflow={cl"
            "amp\|ring}]` — go to the nextpage inside an element, with "
            "the "
            "specified`id`;`div-action://set_previous_item?id=[&overflow"
            "={clamp\|ring}]` — go to theprevious page inside an "
            "element, with the specified `id`.</p><p>The "
            "optional`overflow` parameter is used to set navigation when "
            "the first or last element isreached:`clamp` — transition "
            "will stop at the border element;`ring` — go to thebeginning "
            "or end, depending on the current element.</p><p>By default, "
            "`clamp`."
        ),
    )
    layout_mode: div_pager_layout_mode.DivPagerLayoutMode = Field(
        description=(
            "Type of calculation of the main page width:`fixed` — from "
            "the fixed width of thenext page "
            "`neighbour_page_width`;`percentage` — from the percentage "
            "value`page_width`."
        ),
    )
    layout_provider: typing.Optional[div_layout_provider.DivLayoutProvider] = Field(
        description="Provides data on the actual size of the element.",
    )
    margins: typing.Optional[div_edge_insets.DivEdgeInsets] = Field(
        description="External margins from the element stroke.",
    )
    orientation: typing.Optional[typing.Union[Expr, DivPagerOrientation]] = Field(
        description="Pager orientation.",
    )
    paddings: typing.Optional[div_edge_insets.DivEdgeInsets] = Field(
        description="Internal margins from the element stroke.",
    )
    page_transformation: typing.Optional[div_page_transformation.DivPageTransformation] = Field(
        description="Page transformation during pager scrolling.",
    )
    restrict_parent_scroll: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "If the parameter is enabled, the pager won\'t transmit the "
            "scroll gesture to theparent element."
        ),
    )
    reuse_id: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "ID for the div object structure. Used to optimize block "
            "reuse. See [blockreuse](../../reuse/reuse.md)."
        ),
    )
    row_span: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Merges cells in a string of the [grid](div-grid.md) "
            "element."
        ),
    )
    selected_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description=(
            "List of [actions](div-action.md) to be executed when "
            "selecting an element in[pager](div-pager.md)."
        ),
    )
    tooltips: typing.Optional[typing.Sequence[div_tooltip.DivTooltip]] = Field(
        description=(
            "Tooltips linked to an element. A tooltip can be shown "
            "by`div-action://show_tooltip?id=`, hidden by "
            "`div-action://hide_tooltip?id=` where`id` — tooltip id."
        ),
    )
    transform: typing.Optional[div_transform.DivTransform] = Field(
        description=(
            "Applies the passed transformation to the element. Content "
            "that doesn\'t fit intothe original view area is cut off."
        ),
    )
    transition_change: typing.Optional[div_change_transition.DivChangeTransition] = Field(
        description=(
            "Change animation. It is played when the position or size of "
            "an element changes inthe new layout."
        ),
    )
    transition_in: typing.Optional[div_appearance_transition.DivAppearanceTransition] = Field(
        description=(
            "Appearance animation. It is played when an element with a "
            "new ID appears. Tolearn more about the concept of "
            "transitions, see "
            "[Animatedtransitions](../../interaction#animation/transitio"
            "n-animation)."
        ),
    )
    transition_out: typing.Optional[div_appearance_transition.DivAppearanceTransition] = Field(
        description=(
            "Disappearance animation. It is played when an element "
            "disappears in the newlayout."
        ),
    )
    transition_triggers: typing.Optional[typing.Sequence[typing.Union[Expr, div_transition_trigger.DivTransitionTrigger]]] = Field(
        min_items=1, 
        description=(
            "Animation starting triggers. Default value: `[state_change, "
            "visibility_change]`."
        ),
    )
    variable_triggers: typing.Optional[typing.Sequence[div_trigger.DivTrigger]] = Field(
        description="Triggers for changing variables within an element.",
    )
    variables: typing.Optional[typing.Sequence[div_variable.DivVariable]] = Field(
        description=(
            "Declaration of variables that can be used within an "
            "element. Variables declaredin this array can only be used "
            "within the element and its child elements."
        ),
    )
    visibility: typing.Optional[typing.Union[Expr, div_visibility.DivVisibility]] = Field(
        description="Element visibility.",
    )
    visibility_action: typing.Optional[div_visibility_action.DivVisibilityAction] = Field(
        description=(
            "Tracking visibility of a single element. Not used if the "
            "`visibility_actions`parameter is set."
        ),
    )
    visibility_actions: typing.Optional[typing.Sequence[div_visibility_action.DivVisibilityAction]] = Field(
        description="Actions when an element appears on the screen.",
    )
    width: typing.Optional[div_size.DivSize] = Field(
        description="Element width.",
    )


class DivPagerOrientation(str, enum.Enum):
    HORIZONTAL = "horizontal"
    VERTICAL = "vertical"


DivPager.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_evaluable_type


# Function argument.
class DivFunctionArgument(BaseDiv):

    def __init__(
        self, *,
        name: typing.Optional[typing.Union[Expr, str]] = None,
        type: typing.Optional[typing.Union[Expr, div_evaluable_type.DivEvaluableType]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            name=name,
            type=type,
            **kwargs,
        )

    name: typing.Union[Expr, str] = Field(
        description="Function argument name.",
    )
    type: typing.Union[Expr, div_evaluable_type.DivEvaluableType] = Field(
        description="Function argument type.",
    )


DivFunctionArgument.update_forward_refs()
